EditorCustomStyle

Struct EditorCustomStyle 

pub struct EditorCustomStyle(/* private fields */);
The custom style elements that are specific to an Editor.

Implementations

Source

impl EditorCustomStyle

pub fn hide_gutter(self, hide: bool) -> EditorCustomStyle

Sets whether the gutter should be hidden.

pub fn gutter_accent_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the text accent color of the gutter.

This is the color of the line number for the current line. It will default to the current Text Color

pub fn gutter_dim_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the text dim color of the gutter.

This is the color of the line number for all lines except the current line. If this is not specified it will default to the gutter accent color.

pub fn gutter_left_padding(self, padding: f64) -> EditorCustomStyle

Sets the padding to the left of the numbers in the gutter.

pub fn gutter_right_padding(self, padding: f64) -> EditorCustomStyle

Sets the padding to the right of the numbers in the gutter.

pub fn gutter_current_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the background color of the current line in the gutter

pub fn selection_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the background color to be applied around selected text.

pub fn indent_style(self, indent_style: IndentStyle) -> EditorCustomStyle

Sets the indent style.

pub fn indent_guide_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the color of the indent guide.

pub fn wrap_method(self, wrap: WrapMethod) -> EditorCustomStyle

Sets the method for wrapping lines.

pub fn cursor_color(self, cursor: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the color of the cursor.

pub fn scroll_beyond_last_line(self, scroll_beyond: bool) -> EditorCustomStyle

Allow scrolling beyond the last line of the document.

pub fn current_line_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the background color of the current line.

pub fn visible_whitespace(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the color of visible whitespace characters.

pub fn render_white_space( self, render_white_space: RenderWhitespace, ) -> EditorCustomStyle

Sets which white space characters should be rendered.

pub fn cursor_surrounding_lines(self, lines: usize) -> EditorCustomStyle

Set the number of lines to keep visible above and below the cursor. Default: 1

pub fn indent_guide(self, show: bool) -> EditorCustomStyle

Sets whether the indent guides should be displayed.

pub fn modal(self, modal: bool) -> EditorCustomStyle

Sets the editor’s mode to modal or non-modal.

pub fn modal_relative_line(self, modal_relative_line: bool) -> EditorCustomStyle

Determines if line numbers are relative in modal mode.

pub fn smart_tab(self, smart_tab: bool) -> EditorCustomStyle

Enables or disables smart tab behavior, which inserts the indent style detected in the file when the tab key is pressed.

pub fn phantom_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the color of phantom text

pub fn placeholder_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle

Sets the color of the placeholder text.

pub fn preedit_underline_color( self, color: AlphaColor<Srgb>, ) -> EditorCustomStyle

Sets the color of the underline for preedit text.