pub struct TextEditor { /* private fields */ }Expand description
A text editor view built on top of Editor. See text_editor.
Note: this requires that the document underlying it is a TextDocument for the use of some
logic.
Implementations
Sourceimpl TextEditor
impl TextEditor
Sourcepub fn editor_style(
self,
style: impl Fn(EditorCustomStyle) -> EditorCustomStyle + 'static,
) -> TextEditor
pub fn editor_style( self, style: impl Fn(EditorCustomStyle) -> EditorCustomStyle + 'static, ) -> TextEditor
Sets the custom style properties of the TextEditor.
Sourcepub fn with_editor(self, f: impl FnOnce(&Editor)) -> TextEditor
pub fn with_editor(self, f: impl FnOnce(&Editor)) -> TextEditor
Allows for creation of a TextEditor with an existing Editor.
Sourcepub fn with_editor_mut(self, f: impl FnOnce(&mut Editor)) -> TextEditor
pub fn with_editor_mut(self, f: impl FnOnce(&mut Editor)) -> TextEditor
Allows for creation of a TextEditor with an existing mutable Editor.
Sourcepub fn with_doc(self, f: impl FnOnce(&(dyn Document + 'static))) -> TextEditor
pub fn with_doc(self, f: impl FnOnce(&(dyn Document + 'static))) -> TextEditor
Opens the TextEditor with the provided Document.
You should usually not swap this out without good reason.
Sourcepub fn doc(&self) -> Rc<dyn Document>
pub fn doc(&self) -> Rc<dyn Document>
Returns a reference to the underlying Document. This should usually be a TextDocument.
Sourcepub fn try_doc(&self) -> Option<Rc<dyn Document>>
pub fn try_doc(&self) -> Option<Rc<dyn Document>>
Retrieves the Document and subscribes the current reactive scope to updates.
Returns None if the underlying reactive scope has been disposed.
Sourcepub fn try_doc_untracked(&self) -> Option<Rc<dyn Document>>
pub fn try_doc_untracked(&self) -> Option<Rc<dyn Document>>
Retrieves the Document without subscribing to reactive updates.
Returns None if the underlying reactive scope has been disposed.
pub fn rope_text(&self) -> RopeTextVal
Sourcepub fn use_doc(self, doc: Rc<dyn Document>) -> TextEditor
pub fn use_doc(self, doc: Rc<dyn Document>) -> TextEditor
Use a different document in the text editor
Use the same document as another text editor view.
let primary = text_editor();
let secondary = text_editor().share_document(&primary);
stack((
primary,
secondary,
))If you wish for it to also share the styling, consider using TextEditor::shared_editor
instead.
Create a new TextEditor instance from this instance, sharing the document and styling.
let primary = text_editor();
let secondary = primary.shared_editor();Also see the Editor example.
Sourcepub fn styling(self, styling: impl Styling + 'static) -> TextEditor
pub fn styling(self, styling: impl Styling + 'static) -> TextEditor
Sourcepub fn styling_rc(self, styling: Rc<dyn Styling>) -> TextEditor
pub fn styling_rc(self, styling: Rc<dyn Styling>) -> TextEditor
Use an Rc<dyn Styling> to share between different editors.
Sourcepub fn read_only(self) -> TextEditor
pub fn read_only(self) -> TextEditor
Set the text editor to read only.
Equivalent to setting Editor::read_only
Default: false
Sourcepub fn placeholder(self, text: impl Into<String>) -> TextEditor
pub fn placeholder(self, text: impl Into<String>) -> TextEditor
Set the placeholder text that is displayed when the document is empty.
Can span multiple lines.
This is per-editor, not per-document.
Equivalent to calling TextDocument::add_placeholder
Default: None
Note: only works for the default backing TextDocument doc
Sourcepub fn pre_command(
self,
f: impl Fn(PreCommand<'_>) -> CommandExecuted + 'static,
) -> TextEditor
pub fn pre_command( self, f: impl Fn(PreCommand<'_>) -> CommandExecuted + 'static, ) -> TextEditor
When commands are run on the document, this function is called.
If it returns CommandExecuted::Yes then further handlers after it, including the
default handler, are not executed.
use floem::views::editor::command::{Command, CommandExecuted};
use floem::views::text_editor::text_editor;
use floem_editor_core::command::EditCommand;
text_editor("Hello")
.pre_command(|ev| {
if matches!(ev.cmd, Command::Edit(EditCommand::Undo)) {
// Sorry, no undoing allowed
CommandExecuted::Yes
} else {
CommandExecuted::No
}
})
.pre_command(|_| {
// This will never be called if command was an undo
CommandExecuted::Yes
})
.pre_command(|_| {
// This will never be called
CommandExecuted::No
});Note that these are specific to each text editor view.
Note: only works for the default backing TextDocument doc
Sourcepub fn update(self, f: impl Fn(OnUpdate<'_>) + 'static) -> TextEditor
pub fn update(self, f: impl Fn(OnUpdate<'_>) + 'static) -> TextEditor
Listen for deltas applied to the editor.
Useful for anything that has positions based in the editor that can be updated after typing, such as syntax highlighting.
Note: only works for the default backing TextDocument doc