pub struct EditorCustomStyle(/* private fields */);Expand description
The custom style elements that are specific to an Editor.
Implementations
Sourceimpl EditorCustomStyle
impl EditorCustomStyle
Sourcepub fn hide_gutter(self, hide: bool) -> EditorCustomStyle
pub fn hide_gutter(self, hide: bool) -> EditorCustomStyle
Sets whether the gutter should be hidden.
Sourcepub fn gutter_accent_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn gutter_accent_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the text accent color of the gutter.
This is the color of the line number for the current line. It will default to the current Text Color
Sourcepub fn gutter_dim_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn gutter_dim_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the text dim color of the gutter.
This is the color of the line number for all lines except the current line. If this is not specified it will default to the gutter accent color.
Sourcepub fn gutter_left_padding(self, padding: f64) -> EditorCustomStyle
pub fn gutter_left_padding(self, padding: f64) -> EditorCustomStyle
Sets the padding to the left of the numbers in the gutter.
Sourcepub fn gutter_right_padding(self, padding: f64) -> EditorCustomStyle
pub fn gutter_right_padding(self, padding: f64) -> EditorCustomStyle
Sets the padding to the right of the numbers in the gutter.
Sourcepub fn gutter_current_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn gutter_current_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the background color of the current line in the gutter
Sourcepub fn selection_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn selection_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the background color to be applied around selected text.
Sourcepub fn indent_style(self, indent_style: IndentStyle) -> EditorCustomStyle
pub fn indent_style(self, indent_style: IndentStyle) -> EditorCustomStyle
Sets the indent style.
Sourcepub fn indent_guide_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn indent_guide_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the color of the indent guide.
Sourcepub fn wrap_method(self, wrap: WrapMethod) -> EditorCustomStyle
pub fn wrap_method(self, wrap: WrapMethod) -> EditorCustomStyle
Sets the method for wrapping lines.
Sourcepub fn cursor_color(self, cursor: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn cursor_color(self, cursor: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the color of the cursor.
Sourcepub fn scroll_beyond_last_line(self, scroll_beyond: bool) -> EditorCustomStyle
pub fn scroll_beyond_last_line(self, scroll_beyond: bool) -> EditorCustomStyle
Allow scrolling beyond the last line of the document.
Sourcepub fn current_line_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn current_line_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the background color of the current line.
Sourcepub fn visible_whitespace(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn visible_whitespace(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the color of visible whitespace characters.
Sourcepub fn render_white_space(
self,
render_white_space: RenderWhitespace,
) -> EditorCustomStyle
pub fn render_white_space( self, render_white_space: RenderWhitespace, ) -> EditorCustomStyle
Sets which white space characters should be rendered.
Sourcepub fn cursor_surrounding_lines(self, lines: usize) -> EditorCustomStyle
pub fn cursor_surrounding_lines(self, lines: usize) -> EditorCustomStyle
Set the number of lines to keep visible above and below the cursor.
Default: 1
Sourcepub fn indent_guide(self, show: bool) -> EditorCustomStyle
pub fn indent_guide(self, show: bool) -> EditorCustomStyle
Sets whether the indent guides should be displayed.
Sourcepub fn modal(self, modal: bool) -> EditorCustomStyle
pub fn modal(self, modal: bool) -> EditorCustomStyle
Sets the editor’s mode to modal or non-modal.
Sourcepub fn modal_relative_line(self, modal_relative_line: bool) -> EditorCustomStyle
pub fn modal_relative_line(self, modal_relative_line: bool) -> EditorCustomStyle
Determines if line numbers are relative in modal mode.
Sourcepub fn smart_tab(self, smart_tab: bool) -> EditorCustomStyle
pub fn smart_tab(self, smart_tab: bool) -> EditorCustomStyle
Enables or disables smart tab behavior, which inserts the indent style detected in the file when the tab key is pressed.
Sourcepub fn phantom_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn phantom_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the color of phantom text
Sourcepub fn placeholder_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
pub fn placeholder_color(self, color: AlphaColor<Srgb>) -> EditorCustomStyle
Sets the color of the placeholder text.
Sourcepub fn preedit_underline_color(
self,
color: AlphaColor<Srgb>,
) -> EditorCustomStyle
pub fn preedit_underline_color( self, color: AlphaColor<Srgb>, ) -> EditorCustomStyle
Sets the color of the underline for preedit text.